@@ -1,7 +1,7 @@
 # ABSTRACT: Utilities for Monitoring ElasticSearch
 package App::ElasticSearch::Utilities;
 
-our $VERSION = '4.1'; # VERSION
+our $VERSION = '4.2'; # VERSION
 
 use strict;
 use warnings;
@@ -88,7 +88,7 @@ foreach my $config_file (@_CONFIGS) {
         debug({color=>"red"}, "[$config_file] $@");
     };
 }
-%_GLOBALS = %{ clone_merge(@ConfigData) };
+%_GLOBALS  = @ConfigData ? %{ clone_merge(@ConfigData) } : ();
 
 # Set defaults
 my %DEF = (
@@ -613,7 +613,7 @@ App::ElasticSearch::Utilities - Utilities for Monitoring ElasticSearch
 
 =head1 VERSION
 
-version 4.1
+version 4.2
 
 =head1 SYNOPSIS
 
@@ -914,4 +914,38 @@ Takumi Sakamoto <takumi.saka@gmail.com>
 
 =back
 
+=for :stopwords cpan testmatrix url annocpan anno bugtracker rt cpants kwalitee diff irc mailto metadata placeholders metacpan
+
+=head1 SUPPORT
+
+=head2 Websites
+
+The following websites have more information about this module, and may be of help to you. As always,
+in addition to those websites please use your favorite search engine to discover more resources.
+
+=over 4
+
+=item *
+
+MetaCPAN
+
+A modern, open-source CPAN search engine, useful to view POD in HTML format.
+
+L<http://metacpan.org/release/App-ElasticSearch-Utilities>
+
+=item *
+
+RT: CPAN's Bug Tracker
+
+The RT ( Request Tracker ) website is the default bug/issue tracking system for CPAN.
+
+L<https://rt.cpan.org/Public/Dist/Display.html?Name=App-ElasticSearch-Utilities>
+
+=back
+
+=head2 Source Code
+
+This module's source code is available by visiting:
+L<https://github.com/reyjrar/es-utils>
+
 =cut
